@@ -16,7 +16,7 @@ import re
 import fitz
 
 from pyxllib.prog.newbie import round_int, RunOnlyOnce, decode_bitflags
-from pyxllib.prog.pupil import DictTool, EnchantBase, EnchantCvt
+from pyxllib.prog.pupil import DictTool, inject_members
 from pyxllib.algo.newbie import round_unit
 from pyxllib.algo.pupil import get_number_width
 from pyxllib.file.specialist import File, Dir, writefile, get_etag
@@ -38,7 +38,7 @@ class FitzDoc:
         self.src_file = File(file)
         self.doc = fitz.open(str(file))
 
-    def to_images(self, dst_dir=None, file_fmt='{filestem}_{number}.png', num_width=None, *,
+    def to_images(self, dst_dir=None, file_fmt='{filestem}_{number}.jpg', num_width=None, *,
                   scale=1, start=1, fmt_onepage=False):
         """ 将pdf转为若干页图片
 
@@ -125,60 +125,45 @@ class FitzDoc:
         return getattr(self.doc, item)
 
 
-class EnchantFitzPage(EnchantBase):
+class XlFitzPage(fitz.fitz.Page):
     """ 对fitz.fitz.Page的扩展成员方法 """
 
-    @classmethod
-    @RunOnlyOnce
-    def enchant(cls):
-        names = cls.check_enchant_names([fitz.fitz.Page])
-        cls_methods = {'parse_flags'}
-
-        cls._enchant(fitz.fitz.Page, cls_methods, EnchantCvt.staticmethod2classmethod)
-        cls._enchant(fitz.fitz.Page, names - cls_methods)
-
-    @staticmethod
-    def get_svg_image2(_self, scale=1):
+    def get_svg_image2(self, scale=1):
         # svg 是一段表述性文本
         if scale != 1:
-            txt = _self.get_svg_image(matrix=fitz.Matrix(scale, scale))
+            txt = self.get_svg_image(matrix=fitz.Matrix(scale, scale))
         else:
-            txt = _self.get_svg_image()
+            txt = self.get_svg_image()
         return txt
 
-    @staticmethod
-    def _get_png_data(_self, scale=1):
+    def _get_png_data(self, scale=1):
         # TODO 增加透明通道？
         if scale != 1:
-            pix = _self.get_pixmap(matrix=fitz.Matrix(scale, scale))  # 长宽放大到scale倍
+            pix = self.get_pixmap(matrix=fitz.Matrix(scale, scale))  # 长宽放大到scale倍
         else:
-            pix = _self.get_pixmap()
+            pix = self.get_pixmap()
         return pix.tobytes()
 
-    @staticmethod
-    def get_cv_image(_self, scale=1):
-        return xlcv.read_from_buffer(_self._get_png_data(scale), flags=1)
+    def get_cv_image(self, scale=1):
+        return xlcv.read_from_buffer(self._get_png_data(scale), flags=1)
 
-    @staticmethod
-    def get_pil_image(_self, scale=1):
+    def get_pil_image(self, scale=1):
         # TODO 可以优化，直接从内存数据转pil，不用这样先转cv再转pil
-        return xlpil.read_from_buffer(_self._get_png_data(scale), flags=1)
+        return xlpil.read_from_buffer(self._get_png_data(scale), flags=1)
 
-    @staticmethod
-    def to_image(_self, outfile, *, scale=1, if_exists=None):
+    def to_image(self, outfile, *, scale=1, if_exists=None):
         """ 转成为文件 """
         f = File(outfile)
         suffix = f.suffix.lower()
 
         if suffix == '.svg':
-            content = _self.get_svg_image()
+            content = self.get_svg_image()
             f.write(content, if_exists=if_exists)
         else:
-            im = _self.get_cv_image(scale)
+            im = self.get_cv_image(scale)
             xlcv.write(im, if_exists=if_exists)
 
-    @staticmethod
-    def get_labelme_shapes(_self, opt='dict', *, views=1, scale=1):
+    def get_labelme_shapes(self, opt='dict', *, views=1, scale=1):
         """ 得到labelme版本的shapes标注信息
 
         :param opt: get_text的参数，默认使用无字符集标注的精简的dict
@@ -223,7 +208,7 @@ class EnchantFitzPage(EnchantBase):
             views += [0] * (4 - len(views))
 
         shapes = []
-        page_dict = _self.get_text(opt)
+        page_dict = self.get_text(opt)
 
         # 2 辅助函数
         def add_shape(name, refdict, add_keys, drop_keys=('bbox',)):
@@ -271,18 +256,17 @@ class EnchantFitzPage(EnchantBase):
 
         return shapes
 
-    @staticmethod
-    def parse_flags(_cls, n):
+    @classmethod
+    def parse_flags(cls, n):
         """ 解析spans的flags参数明文含义 """
         flags = decode_bitflags(n, ('superscript', 'italic', 'serifed', 'monospaced', 'bold'))
         flags['sans'] = not flags['serifed']
         flags['proportional'] = not flags['monospaced']
         return flags
 
-    @staticmethod
-    def browser(_self, opt='html'):
+    def browser(self, opt='html'):
         if opt == 'html':
-            data = _self.get_text('html')  # html、xhtml 可以转网页，虽然排版相对来说还是会乱一点
+            data = self.get_text('html')  # html、xhtml 可以转网页，虽然排版相对来说还是会乱一点
             data = ''.join(data)
             etag = get_etag(data)
             f = File(etag, Dir.TEMP, suffix='.html')
@@ -292,7 +276,7 @@ class EnchantFitzPage(EnchantBase):
             raise ValueError
 
 
-EnchantFitzPage.enchant()
+inject_members(XlFitzPage, fitz.fitz.Page)
 
 
 class DemoFitz:
